[![License: GPL v3](https://img.shields.io/badge/License-GPL%20v3-blue.svg)](http://www.gnu.org/licenses/gpl-3.0)
[![Build Status](https://travis-ci.org/aldro61/pyscm.svg?branch=master)](https://travis-ci.org/aldro61/pyscm)
[![DOI](https://zenodo.org/badge/17353131.svg)](https://zenodo.org/badge/latestdoi/17353131)


# pySCM

A fast implementation of the Set Covering Machine algorithm using a dynamic programming algorithm to select the rules of greatest utility.

Marchand, M., & Taylor, J. S. (2003). The set covering machine. Journal of Machine Learning Research, 3, 723–746.

![Alt text](https://github.com/aldro61/pyscm/raw/master/examples/decision_boundary.png)

## Installation

``` 
pip install pyscm-ml
```
or locally with

``` 
python -m pip install -e .
```

## Running tests
```
python -m pip install pytest
python -m pytest
```

## Contributors
 * [Alexandre Drouin](http://graal.ift.ulaval.ca/adrouin) (package maintainer)
 * [Baptiste Bauvin](https://github.com/babau1)
 * [Francis Brochu](https://github.com/PhrankBrochu)
 * [Gaël Letarte St-Pierre](https://github.com/gletarte)
 * [Mazid Osseni](https://github.com/dizam92)
 * [Pier-Luc Plante](https://github.com/plpla)
 * [Thibaud Godon](https://github.com/thibgo)
